@@ -38,17 +38,13 @@ static PyObject* basicparsegen_iternext(PyObject *self)
 
 
 PyTypeObject BasicParseGen_Type = {
-#if PY_MAJOR_VERSION >= 3
 	PyVarObject_HEAD_INIT(NULL, 0)
-#else
-	PyObject_HEAD_INIT(NULL)
-#endif
 	.tp_basicsize = sizeof(BasicParseGen),
 	.tp_name = "_yajl2.basic_parse",
 	.tp_doc = "Generator of (evt,value)",
 	.tp_init = (initproc)basicparsegen_init,
 	.tp_dealloc = (destructor)basicparsegen_dealloc,
-	.tp_flags = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_ITER,
+	.tp_flags = Py_TPFLAGS_DEFAULT,
 	.tp_iter = ijson_return_self,
 	.tp_iternext = basicparsegen_iternext
 };
