@@ -3,14 +3,12 @@
 import asyncio
 import io
 
-from ijson import compat
-
 from ._test_async_common import _get_all, _get_first
 
 
 class AsyncReader(object):
     def __init__(self, data):
-        if type(data) == compat.bytetype:
+        if type(data) == bytes:
             self.data = io.BytesIO(data)
         else:
             self.data = io.StringIO(data)
