@@ -3,13 +3,11 @@
 import io
 import types
 
-from ijson import compat
-
 from ._test_async_common import _get_all, _get_first
 
 class AsyncReaderTypesCoroutine(object):
     def __init__(self, data):
-        if type(data) == compat.bytetype:
+        if type(data) == bytes:
             self.data = io.BytesIO(data)
         else:
             self.data = io.StringIO(data)
